@@ -14,14 +14,9 @@ impl ResticCreate {
         let restic = GenericExecutable::find("restic")?;
         let tags = tags.into_iter().map(|a| a.to_string()).collect::<Vec<_>>().join(",");
         
-        // Get the command specific flags
-        let flags = config.restic.flags.as_ref()
-            .and_then(|f| f.backup.clone())
-            .unwrap_or(Vec::new());
-
         // Create the executable flags
         let args = vec!["backup", "--tag", &tags].into_iter()
-            .chain(flags.iter().map(|f| f.as_str()))
+            .chain(config.restic.flags.backup.iter().map(|f| f.as_str()))
             .chain(vec![config.restic.dir.as_str()]);
 
         // Create the executable
