@@ -12,6 +12,7 @@ pub struct ResticListArchive {
     /// The name of the host who creates the archive
     pub hostname: String,
     /// The tags associated with the archive
+    #[serde(default)]
     pub tags: Vec<String>,
     /// The ID of the archive
     pub id: String,
@@ -41,6 +42,7 @@ impl ResticList {
     /// Lists the repository archives
     pub fn exec(self) -> Result<ResticListOutput> {
         let output_json = self.exec.exec_stringout()?;
-        serde_json::from_str(&output_json).map_err(|e| einval!("Unexpected JSON output from `restic` command ({})", e))
+        serde_json::from_str(&output_json)
+            .map_err(|e| einval!("Unexpected JSON output from `restic` command ({})", e))
     }
 }
